@@ -1,2 +1,2 @@
-from utils import SsdbResponseUtils
 from .ssdb_client import SsdbClient
+from .utils import SsdbResponseUtils
